pub struct KeymapHelp { /* private fields */ }Expand description
Complete, vertically scrollable help generated from active keymap bindings.

Implementations
Sourceimpl KeymapHelp
impl KeymapHelp
Sourcepub fn from_keymap<C: Clone>(keymap: &Keymap<C>) -> Self
pub fn from_keymap<C: Clone>(keymap: &Keymap<C>) -> Self
Build help rows from active, labeled bindings in a keymap.
Sourcepub fn from_hints<C>(hints: impl IntoIterator<Item = Hint<C>>) -> Self
pub fn from_hints<C>(hints: impl IntoIterator<Item = Hint<C>>) -> Self
Build help rows from discovered bindings.