pub struct DockSpec { /* private fields */ }Expand description
Responsive geometry policy for one dockable panel.
Implementations
Sourceimpl DockSpec
impl DockSpec
Sourcepub const fn right(breakpoint: u16, panel_width: u16) -> Self
pub const fn right(breakpoint: u16, panel_width: u16) -> Self
Put a panel on the right, docking at breakpoint columns and using at
most panel_width columns.
Sourcepub const fn left(breakpoint: u16, panel_width: u16) -> Self
pub const fn left(breakpoint: u16, panel_width: u16) -> Self
Put a panel on the left, docking at breakpoint columns and using at
most panel_width columns.
Sourcepub const fn breakpoint(self) -> u16
pub const fn breakpoint(self) -> u16
Width at which a visible panel becomes docked instead of a drawer.
Sourcepub const fn panel_width(self) -> u16
pub const fn panel_width(self) -> u16
Preferred panel width. Resolution clamps it to at least one column and at most the available frame width.