Key

Struct Key 

pub struct Key {
    pub code: KeyCode,
    pub ctrl: bool,
    pub alt: bool,
    pub shift: bool,
}
A key press with its modifier state.

Fields

code: KeyCode

The logical key value that was pressed.

ctrl: bool

Ctrl held during the press.

alt: bool

Alt held during the press.

shift: bool

Shift held during the press.

Implementations

Source

impl Key

pub fn new(code: KeyCode) -> Self

A key with the given code and no modifiers held.

pub fn plain(&self) -> bool

True when neither Ctrl nor Alt is held (Shift is ignored, as it is already folded into the character for text input).