pub struct Scrollbar { /* private fields */ }Expand description
A scrollbar for a VirtualWindow.
The same component draws vertical and horizontal bars, uses the active theme by default, and permits local glyph/style overrides. It draws nothing when the whole collection fits in the window.

Implementations
Sourceimpl Scrollbar
impl Scrollbar
Sourcepub fn vertical(window: VirtualWindow) -> Self
pub fn vertical(window: VirtualWindow) -> Self
Create a vertical scrollbar for window.
Sourcepub fn horizontal(window: VirtualWindow) -> Self
pub fn horizontal(window: VirtualWindow) -> Self
Create a horizontal scrollbar for window.
Sourcepub fn track_glyph(self, glyph: char) -> Self
pub fn track_glyph(self, glyph: char) -> Self
Replace the track glyph.
Sourcepub fn thumb_glyph(self, glyph: char) -> Self
pub fn thumb_glyph(self, glyph: char) -> Self
Replace the thumb glyph.
Sourcepub fn track_style(self, style: Style) -> Self
pub fn track_style(self, style: Style) -> Self
Override the track style for this bar.
Sourcepub fn thumb_style(self, style: Style) -> Self
pub fn thumb_style(self, style: Style) -> Self
Override the thumb style for this bar.